EXPORTS
	??0CBNFParser@@IAE@AAVCAttributeLookupTable@@@Z @ 1 NONAME ; protected: __thiscall CBNFParser::CBNFParser(class CAttributeLookupTable &)
	??0CFragmentedString@@QAE@XZ @ 2 NONAME ; public: __thiscall CFragmentedString::CFragmentedString(void)
	??1CBNFParser@@UAE@XZ @ 3 NONAME ; public: virtual __thiscall CBNFParser::~CBNFParser(void)
	??1CFragmentedString@@UAE@XZ @ 4 NONAME ; public: virtual __thiscall CFragmentedString::~CFragmentedString(void)
	?AddComponentAttributeL@CBNFParser@@QAEXAAVCBNFNode@@PBVTDesC16@@H@Z @ 5 NONAME ; public: void __thiscall CBNFParser::AddComponentAttributeL(class CBNFNode &,class TDesC16 const *,int)
	?AddRuleCallbackL@CBNFParser@@MAEXAAVCBNFNode@@PBVTDesC16@@P6AXAAV1@@Z@Z @ 6 NONAME ; protected: virtual void __thiscall CBNFParser::AddRuleCallbackL(class CBNFNode &,class TDesC16 const *,void (__cdecl*)(class CBNFParser &))
	?AddStringL@CFragmentedString@@QAEXABVTDesC16@@@Z @ 7 NONAME ; public: void __thiscall CFragmentedString::AddStringL(class TDesC16 const &)
	?AddStringL@CFragmentedString@@QAEXPAVHBufC16@@@Z @ 8 NONAME ; public: void __thiscall CFragmentedString::AddStringL(class HBufC16 *)
	?AndL@CBNFParser@@MAEHAAVCBNFNode@@AAW4TStringMatch@CFragmentedString@@@Z @ 9 NONAME ; protected: virtual int __thiscall CBNFParser::AndL(class CBNFNode &,enum CFragmentedString::TStringMatch &)
	?AttributeLUT@CBNFParser@@IBEAAVCAttributeLookupTable@@XZ @ 10 NONAME ; protected: class CAttributeLookupTable & __thiscall CBNFParser::AttributeLUT(void)const 
	?CommitL@CBNFParser@@QAEXXZ @ 11 NONAME ; public: void __thiscall CBNFParser::CommitL(void)
	?ConsumeMatched@CFragmentedString@@QAEXXZ @ 12 NONAME ; public: void __thiscall CFragmentedString::ConsumeMatched(void)
	?ContentL@CFragmentedString@@QBEPAVHBufC16@@XZ @ 13 NONAME ; public: class HBufC16 * __thiscall CFragmentedString::ContentL(void)const 
	?DeleteMark@CFragmentedString@@QAEXXZ @ 14 NONAME ; public: void __thiscall CFragmentedString::DeleteMark(void)
	?DeleteToMark@CFragmentedString@@IAEXABVTStringMark@1@@Z @ 15 NONAME ; protected: void __thiscall CFragmentedString::DeleteToMark(class CFragmentedString::TStringMark const &)
	?EndConditional@CBNFParser@@MAEXW4TParserNodeTypes@@H@Z @ 16 NONAME ; protected: virtual void __thiscall CBNFParser::EndConditional(enum TParserNodeTypes,int)
	?ExactL@CBNFParser@@MAEHAAVCBNFNode@@AAW4TStringMatch@CFragmentedString@@@Z @ 17 NONAME ; protected: virtual int __thiscall CBNFParser::ExactL(class CBNFNode &,enum CFragmentedString::TStringMatch &)
	?ExecutePostRuleCallbackL@CBNFParser@@MAEXAAVCBNFNode@@@Z @ 18 NONAME ; protected: virtual void __thiscall CBNFParser::ExecutePostRuleCallbackL(class CBNFNode &)
	?ExecutePreRuleCallbackL@CBNFParser@@MAEXAAVCBNFNode@@@Z @ 19 NONAME ; protected: virtual void __thiscall CBNFParser::ExecutePreRuleCallbackL(class CBNFNode &)
	?InsertStringL@CFragmentedString@@QAEXPAVHBufC16@@@Z @ 20 NONAME ; public: void __thiscall CFragmentedString::InsertStringL(class HBufC16 *)
	?InsertStringToL@CFragmentedString@@IAEXPAVHBufC16@@HH@Z @ 21 NONAME ; protected: void __thiscall CFragmentedString::InsertStringToL(class HBufC16 *,int,int)
	?Length@CFragmentedString@@QBEHXZ @ 22 NONAME ; public: int __thiscall CFragmentedString::Length(void)const 
	?MDataProviderObserverReserved1@CBNFParser@@UAEXXZ @ 23 NONAME ; public: virtual void __thiscall CBNFParser::MDataProviderObserverReserved1(void)
	?MDataProviderObserverReserved2@CBNFParser@@UAEXXZ @ 24 NONAME ; public: virtual void __thiscall CBNFParser::MDataProviderObserverReserved2(void)
	?Mark@CFragmentedString@@QAEXXZ @ 25 NONAME ; public: void __thiscall CFragmentedString::Mark(void)
	?MarkCallback@CBNFParser@@KAXAAV1@@Z @ 26 NONAME ; protected: static void __cdecl CBNFParser::MarkCallback(class CBNFParser &)
	?MarkedL@CFragmentedString@@QAEPAVHBufC16@@XZ @ 27 NONAME ; public: class HBufC16 * __thiscall CFragmentedString::MarkedL(void)
	?MarkedWithInitialTextL@CFragmentedString@@QAEPAVHBufC16@@ABVTDesC16@@@Z @ 28 NONAME ; public: class HBufC16 * __thiscall CFragmentedString::MarkedWithInitialTextL(class TDesC16 const &)
	?Match@CFragmentedString@@QAE?AW4TStringMatch@1@ABVTDesC16@@@Z @ 29 NONAME ; public: enum CFragmentedString::TStringMatch  __thiscall CFragmentedString::Match(class TDesC16 const &)
	?MatchNotSelect@CFragmentedString@@QAE?AW4TStringMatch@1@ABVTDesC16@@@Z @ 30 NONAME ; public: enum CFragmentedString::TStringMatch  __thiscall CFragmentedString::MatchNotSelect(class TDesC16 const &)
	?MatchRange@CFragmentedString@@QAE?AW4TStringMatch@1@II@Z @ 31 NONAME ; public: enum CFragmentedString::TStringMatch  __thiscall CFragmentedString::MatchRange(unsigned int,unsigned int)
	?MatchSelect@CFragmentedString@@QAE?AW4TStringMatch@1@ABVTDesC16@@@Z @ 32 NONAME ; public: enum CFragmentedString::TStringMatch  __thiscall CFragmentedString::MatchSelect(class TDesC16 const &)
	?NMoreL@CBNFParser@@MAEHAAVCBNFNode@@AAW4TStringMatch@CFragmentedString@@@Z @ 33 NONAME ; protected: virtual int __thiscall CBNFParser::NMoreL(class CBNFNode &,enum CFragmentedString::TStringMatch &)
	?NewBNFL@CBNFParser@@QAEPAVCBNFNode@@XZ @ 34 NONAME ; public: class CBNFNode * __thiscall CBNFParser::NewBNFL(void)
	?NewComponentL@CBNFParser@@QAEAAVCBNFNode@@AAV2@W4TParserNodeTypes@@ABVTDesC16@@@Z @ 35 NONAME ; public: class CBNFNode & __thiscall CBNFParser::NewComponentL(class CBNFNode &,enum TParserNodeTypes,class TDesC16 const &)
	?NewComponentL@CBNFParser@@QAEAAVCBNFNode@@AAV2@W4TParserNodeTypes@@PAVHBufC16@@P6AXAAV1@@ZP6AX3@Z@Z @ 36 NONAME ; public: class CBNFNode & __thiscall CBNFParser::NewComponentL(class CBNFNode &,enum TParserNodeTypes,class HBufC16 *,void (__cdecl*)(class CBNFParser &),void (__cdecl*)(class CBNFParser &))
	?NewComponentL@CBNFParser@@QAEAAVCBNFNode@@PAV2@AAV2@ABVTDesC16@@@Z @ 37 NONAME ; public: class CBNFNode & __thiscall CBNFParser::NewComponentL(class CBNFNode *,class CBNFNode &,class TDesC16 const &)
	?NewComponentL@CBNFParser@@QAEPAVCBNFNode@@PAV2@ABVTDesC16@@@Z @ 38 NONAME ; public: class CBNFNode * __thiscall CBNFParser::NewComponentL(class CBNFNode *,class TDesC16 const &)
	?NewComponentL@CBNFParser@@QAEPAVCBNFNode@@W4TParserNodeTypes@@ABVTDesC16@@@Z @ 39 NONAME ; public: class CBNFNode * __thiscall CBNFParser::NewComponentL(enum TParserNodeTypes,class TDesC16 const &)
	?NewComponentL@CBNFParser@@QAEPAVCBNFNode@@W4TParserNodeTypes@@PAVHBufC16@@P6AXAAV1@@ZP6AX2@Z@Z @ 40 NONAME ; public: class CBNFNode * __thiscall CBNFParser::NewComponentL(enum TParserNodeTypes,class HBufC16 *,void (__cdecl*)(class CBNFParser &),void (__cdecl*)(class CBNFParser &))
	?NewL@CBNFParser@@SAPAV1@AAVCAttributeLookupTable@@@Z @ 41 NONAME ; public: static class CBNFParser * __cdecl CBNFParser::NewL(class CAttributeLookupTable &)
	?NewRuleL@CBNFParser@@QAEAAVCBNFNode@@PAV2@ABVTDesC16@@W4TParserNodeTypes@@1P6AXAAV1@@ZP6AX3@Z@Z @ 42 NONAME ; public: class CBNFNode & __thiscall CBNFParser::NewRuleL(class CBNFNode *,class TDesC16 const &,enum TParserNodeTypes,class TDesC16 const &,void (__cdecl*)(class CBNFParser &),void (__cdecl*)(class CBNFParser &))
	?NewRuleL@CBNFParser@@QAEAAVCBNFNode@@PAV2@ABVTDesC16@@W4TParserNodeTypes@@PAVHBufC16@@P6AXAAV1@@ZP6AX4@Z@Z @ 43 NONAME ; public: class CBNFNode & __thiscall CBNFParser::NewRuleL(class CBNFNode *,class TDesC16 const &,enum TParserNodeTypes,class HBufC16 *,void (__cdecl*)(class CBNFParser &),void (__cdecl*)(class CBNFParser &))
	?OptionalL@CBNFParser@@MAEHAAVCBNFNode@@AAW4TStringMatch@CFragmentedString@@@Z @ 44 NONAME ; protected: virtual int __thiscall CBNFParser::OptionalL(class CBNFNode &,enum CFragmentedString::TStringMatch &)
	?OrL@CBNFParser@@MAEHAAVCBNFNode@@AAW4TStringMatch@CFragmentedString@@@Z @ 45 NONAME ; protected: virtual int __thiscall CBNFParser::OrL(class CBNFNode &,enum CFragmentedString::TStringMatch &)
	?ParseL@CBNFParser@@IAEHXZ @ 46 NONAME ; protected: int __thiscall CBNFParser::ParseL(void)
	?PerformRuleL@CBNFParser@@MAEHAAVCBNFNode@@AAW4TStringMatch@CFragmentedString@@@Z @ 47 NONAME ; protected: virtual int __thiscall CBNFParser::PerformRuleL(class CBNFNode &,enum CFragmentedString::TStringMatch &)
	?ProcessDataL@CBNFParser@@UAEXAAVHBufC8@@@Z @ 48 NONAME ; public: virtual void __thiscall CBNFParser::ProcessDataL(class HBufC8 &)
	?RangeL@CBNFParser@@MAEHAAVCBNFNode@@AAW4TStringMatch@CFragmentedString@@@Z @ 49 NONAME ; protected: virtual int __thiscall CBNFParser::RangeL(class CBNFNode &,enum CFragmentedString::TStringMatch &)
	?ReferenceL@CBNFParser@@MAEHAAVCBNFNode@@AAW4TStringMatch@CFragmentedString@@@Z @ 50 NONAME ; protected: virtual int __thiscall CBNFParser::ReferenceL(class CBNFNode &,enum CFragmentedString::TStringMatch &)
	?ReplaceMarkedAndSkipL@CFragmentedString@@QAEXPAVHBufC16@@@Z @ 51 NONAME ; public: void __thiscall CFragmentedString::ReplaceMarkedAndSkipL(class HBufC16 *)
	?ReplaceMarkedL@CFragmentedString@@QAEXPAVHBufC16@@@Z @ 52 NONAME ; public: void __thiscall CFragmentedString::ReplaceMarkedL(class HBufC16 *)
	?Reset@CFragmentedString@@QAEXXZ @ 53 NONAME ; public: void __thiscall CFragmentedString::Reset(void)
	?ResetL@CBNFParser@@UAEXXZ @ 54 NONAME ; public: virtual void __thiscall CBNFParser::ResetL(void)
	?ResetToMark@CFragmentedString@@QAEXXZ @ 55 NONAME ; public: void __thiscall CFragmentedString::ResetToMark(void)
	?SelectL@CBNFParser@@MAEHAAVCBNFNode@@AAW4TStringMatch@CFragmentedString@@@Z @ 56 NONAME ; protected: virtual int __thiscall CBNFParser::SelectL(class CBNFNode &,enum CFragmentedString::TStringMatch &)
	?SetBaseUriL@CBNFParser@@UAEXPBVTDesC16@@@Z @ 57 NONAME ; public: virtual void __thiscall CBNFParser::SetBaseUriL(class TDesC16 const *)
	?SetDataExpected@CBNFParser@@UAEXH@Z @ 58 NONAME ; public: virtual void __thiscall CBNFParser::SetDataExpected(int)
	?SetDocumentTypeL@CBNFParser@@UAEXABVTDesC16@@0@Z @ 59 NONAME ; public: virtual void __thiscall CBNFParser::SetDocumentTypeL(class TDesC16 const &,class TDesC16 const &)
	?SetDocumentTypeL@CBNFParser@@UAEXABVTDesC16@@@Z @ 60 NONAME ; public: virtual void __thiscall CBNFParser::SetDocumentTypeL(class TDesC16 const &)
	?SetStatus@CBNFParser@@UAEXH@Z @ 61 NONAME ; public: virtual void __thiscall CBNFParser::SetStatus(int)
	?StartConditional@CBNFParser@@MAEXW4TParserNodeTypes@@@Z @ 62 NONAME ; protected: virtual void __thiscall CBNFParser::StartConditional(enum TParserNodeTypes)
	?StringL@CFragmentedString@@QBEPAVHBufC16@@XZ @ 63 NONAME ; public: class HBufC16 * __thiscall CFragmentedString::StringL(void)const 
	?TreeL@CBNFParser@@MAEPAVCBNFNode@@XZ @ 64 NONAME ; protected: virtual class CBNFNode * __thiscall CBNFParser::TreeL(void)
	?WithoutL@CBNFParser@@MAEHAAVCBNFNode@@AAW4TStringMatch@CFragmentedString@@@Z @ 65 NONAME ; protected: virtual int __thiscall CBNFParser::WithoutL(class CBNFNode &,enum CFragmentedString::TStringMatch &)

